@@ -24,15 +24,15 @@ test_that('output from bins_upper is as expected', {
 
 test_that('output from rfm_heatmap_data is as expected', {
 
-  analysis_date <- lubridate::as_date('2006-12-31', tz = 'UTC')
-  
-  actual <- 
+  analysis_date <- lubridate::as_date('2006-12-31')
+
+  actual <-
     rfm_table_order(rfm_data_orders, customer_id, order_date, revenue, analysis_date) %>%
     rfm_heatmap_data() %>%
     dplyr::pull(monetary) %>%
     sum() %>%
     round()
-  
+
   expected <- 12634
   expect_equal(actual, expected)
 
@@ -40,13 +40,13 @@ test_that('output from rfm_heatmap_data is as expected', {
 
 test_that('output from check_levels is as expected', {
 
-  analysis_date <- lubridate::as_date('2006-12-31', tz = 'UTC')
-  
-  actual <- 
+  analysis_date <- lubridate::as_date('2006-12-31')
+
+  actual <-
     rfm_table_order(rfm_data_orders, customer_id, order_date, revenue, analysis_date) %>%
     rfm_heatmap_data() %>%
     check_levels(column = 2)
-  
+
   expected <- c(1, 2, 3, 4, 5)
   expect_equivalent(actual, expected)
 
@@ -54,15 +54,15 @@ test_that('output from check_levels is as expected', {
 
 test_that('output from modify_rfm is as expected', {
 
-  analysis_date <- lubridate::as_date('2006-12-31', tz = 'UTC')
+  analysis_date <- lubridate::as_date('2006-12-31')
 
-  heat <- 
+  heat <-
     rfm_table_order(rfm_data_orders, customer_id, order_date, revenue, analysis_date) %>%
     rfm_heatmap_data()
 
   clevel <- check_levels(heat, column = 2)
 
-  actual <- 
+  actual <-
     modify_rfm(heat, 5, clevel) %>%
     dplyr::pull(monetary) %>%
     sum() %>%
